@@ -188,6 +188,15 @@ void AppendConfigToken( String& rURL, sal_Bool bQuestionMark, const rtl::OUStrin
     rURL += DEFINE_CONST_UNICODE("&System=");
     rURL += SvtHelpOptions().GetSystem();
 
+    static rtl::OUString aVersion;
+    if ( aVersion.isEmpty() )
+        aVersion = utl::Bootstrap::getProductVersion();
+
+    if ( !aVersion.isEmpty() )
+    {
+        rURL += DEFINE_CONST_UNICODE( "&Version=" );
+        rURL += String( aVersion );
+    }
 }
 
 sal_Bool GetHelpAnchor_Impl( const String& _rURL, String& _rAnchor )
@@ -788,7 +797,7 @@ sal_Bool SfxHelp::Start_Impl( const String& rURL, const Window* pWindow, const S
             if ( rURL.Search( sHelpIdScheme ) != 0 )
                 sKeyword = ::rtl::OUString( rURL );
 
-            if ( pWindow && SfxContentHelper::IsHelpErrorDocument( aHelpURL ) )
+            if ( impl_hasHelpInstalled() && pWindow && SfxContentHelper::IsHelpErrorDocument( aHelpURL ) )
             {
                 // no help found -> try with parent help id.
                 Window* pParent = pWindow->GetParent();
