@@ -45,9 +45,10 @@
 #include "editeng/borderline.hxx"
 #include "editeng/boxitem.hxx"
 #include "svx/svdmodel.hxx"
-#include "svdstr.hrc"
-#include "svdglob.hxx"
+#include "svx/svdstr.hrc"
+#include "svx/svdglob.hxx"
 
+using ::editeng::SvxBorderLine;
 using ::rtl::OUString;
 using ::com::sun::star::awt::XLayoutConstrains;
 using namespace ::com::sun::star::uno;
@@ -121,7 +122,7 @@ basegfx::B2ITuple TableLayouter::getCellSize( const CellPos& rPos  ) const
     }
     catch( Exception& )
     {
-        DBG_ERROR( "TableLayouter::getCellSize(), exception caught!" );
+        OSL_FAIL( "TableLayouter::getCellSize(), exception caught!" );
     }
     
     return basegfx::B2ITuple( width, height );
@@ -150,14 +151,13 @@ bool TableLayouter::getCellArea( const CellPos& rPos, basegfx::B2IRectangle& rAr
     }
     catch( Exception& )
     {
-        DBG_ERROR( "TableLayouter::getCellSize(), exception caught!" );
+        OSL_FAIL( "TableLayouter::getCellSize(), exception caught!" );
     }
     return false;
 }
 
 // -----------------------------------------------------------------------------
-
-sal_Int32 TableLayouter::getRowHeight( sal_Int32 nRow )
+sal_Int32 TableLayouter::getRowHeight( sal_Int32 nRow ) const
 {
     if( isValidRow(nRow) )
         return maRows[nRow].mnSize;
@@ -175,13 +175,12 @@ void TableLayouter::setRowHeight( sal_Int32 nRow, sal_Int32 nHeight )
     }
     else
     {
-        DBG_ERROR( "TableLayouter::setRowHeight(), row out of range!" );
+        OSL_FAIL( "TableLayouter::setRowHeight(), row out of range!" );
     }
 }
 
 // -----------------------------------------------------------------------------
-
-sal_Int32 TableLayouter::getColumnWidth( sal_Int32 nColumn )
+sal_Int32 TableLayouter::getColumnWidth( sal_Int32 nColumn ) const
 {
     if( isValidColumn(nColumn) )
         return maColumns[nColumn].mnSize;
@@ -196,7 +195,7 @@ void TableLayouter::setColumnWidth( sal_Int32 nColumn, sal_Int32 nWidth )
     if( isValidColumn(nColumn) )
         maColumns[nColumn].mnSize = nWidth;
     else
-        DBG_ERROR( "TableLayouter::setColumnWidth(), column out of range!" );
+        OSL_FAIL( "TableLayouter::setColumnWidth(), column out of range!" );
 }
 
 // -----------------------------------------------------------------------------
@@ -212,7 +211,7 @@ bool TableLayouter::isEdgeVisible( sal_Int32 nEdgeX, sal_Int32 nEdgeY, bool bHor
     }
     else
     {
-        OSL_ENSURE( false, "sdr::table::TableLayouter::getBorderLine(), invalid edge!" );
+        OSL_FAIL( "sdr::table::TableLayouter::getBorderLine(), invalid edge!" );
     }
 
     return false;
@@ -236,7 +235,7 @@ SvxBorderLine* TableLayouter::getBorderLine( sal_Int32 nEdgeX, sal_Int32 nEdgeY,
     }
     else
     {
-        OSL_ENSURE( false, "sdr::table::TableLayouter::getBorderLine(), invalid edge!" );
+        OSL_FAIL( "sdr::table::TableLayouter::getBorderLine(), invalid edge!" );
     }
 
     return pLine;
@@ -443,7 +442,7 @@ bool findMergeOrigin( const TableModelRef& xTable, sal_Int32 nMergedX, sal_Int32
     }
     catch( Exception& )
     {
-        DBG_ERROR("sdr::table::TableLayouter::findMergeOrigin(), exception caught!");
+        OSL_FAIL("sdr::table::TableLayouter::findMergeOrigin(), exception caught!");
     }
     return false;
 }
@@ -458,7 +457,7 @@ sal_Int32 TableLayouter::getMinimumColumnWidth( sal_Int32 nColumn )
     }
     else
     {
-        DBG_ERROR( "TableLayouter::getMinimumColumnWidth(), column out of range!" );
+        OSL_FAIL( "TableLayouter::getMinimumColumnWidth(), column out of range!" );
         return 0;
     }
 }
@@ -914,7 +913,7 @@ CellRef TableLayouter::getCell( const CellPos& rPos ) const
     }
     catch( Exception& )
     {
-        DBG_ERROR( "sdr::table::TableLayouter::getCell(), exception caught!" );
+        OSL_FAIL( "sdr::table::TableLayouter::getCell(), exception caught!" );
     }
     return xCell;
 }
@@ -928,8 +927,8 @@ bool TableLayouter::HasPriority( const SvxBorderLine* pThis, const SvxBorderLine
     if (!pOther || (pOther == &gEmptyBorder))
         return true;
 
-    USHORT nThisSize = pThis->GetOutWidth() + pThis->GetDistance() + pThis->GetInWidth();
-    USHORT nOtherSize = pOther->GetOutWidth() + pOther->GetDistance() + pOther->GetInWidth();
+    sal_uInt16 nThisSize = pThis->GetOutWidth() + pThis->GetDistance() + pThis->GetInWidth();
+    sal_uInt16 nOtherSize = pOther->GetOutWidth() + pOther->GetDistance() + pOther->GetInWidth();
 
     if (nThisSize > nOtherSize)
         return true;
@@ -1108,7 +1107,7 @@ void TableLayouter::SetLayoutToModel()
     }
     catch( Exception& )
     {
-        DBG_ERROR("sdr::table::TableLayouter::SetLayoutToModel(), exception caught!");
+        OSL_FAIL("sdr::table::TableLayouter::SetLayoutToModel(), exception caught!");
     }
 }
 */
@@ -1147,7 +1146,7 @@ void TableLayouter::DistributeColumns( ::Rectangle& rArea, sal_Int32 nFirstCol,
     catch( Exception& e )
     {
         (void)e;
-        DBG_ERROR("sdr::table::TableLayouter::DistributeColumns(), exception caught!");
+        OSL_FAIL("sdr::table::TableLayouter::DistributeColumns(), exception caught!");
     }
 }
 
@@ -1199,12 +1198,11 @@ void TableLayouter::DistributeRows( ::Rectangle& rArea, sal_Int32 nFirstRow, sal
     catch( Exception& e )
     {
         (void)e;
-        DBG_ERROR("sdr::table::TableLayouter::DistributeRows(), exception caught!");
+        OSL_FAIL("sdr::table::TableLayouter::DistributeRows(), exception caught!");
     }
 }
 
 // -----------------------------------------------------------------------------
-
 void TableLayouter::SetWritingMode( com::sun::star::text::WritingMode eWritingMode )
 {
     meWritingMode = eWritingMode;
@@ -1289,7 +1287,7 @@ sal_Int32 TableLayouter::detectInsertedOrRemovedRows()
     catch( Exception& e )
     {
         (void)e;
-        DBG_ERROR("svx::TableLayouter::detectInsertedOrRemovedRows(), exception caught!");
+        OSL_FAIL("svx::TableLayouter::detectInsertedOrRemovedRows(), exception caught!");
     }
 
     return nHeightChange;
