@@ -31,7 +31,7 @@
 
 // include ---------------------------------------------------------------
 
-#include <string> // HACK: prevent conflict between STLPORT and Workshop headers
+#include <string>
 #include <sfx2/app.hxx>
 #include <sfx2/dispatch.hxx>
 #include <sfx2/objsh.hxx>
@@ -45,8 +45,8 @@
 #define TMP_STR_BEGIN	'['
 #define TMP_STR_END		']'
 
-#include "drawitem.hxx"
-#include "xattr.hxx"
+#include "svx/drawitem.hxx"
+#include "svx/xattr.hxx"
 #include <svx/xtable.hxx>
 #include <svx/fillctrl.hxx>
 #include <svx/itemwin.hxx>
@@ -67,7 +67,7 @@ SFX_IMPL_TOOLBOX_CONTROL( SvxFillToolBoxControl, XFillStyleItem );
 |*
 \************************************************************************/
 
-SvxFillToolBoxControl::SvxFillToolBoxControl( USHORT nSlotId, USHORT nId, ToolBox& rTbx ) :
+SvxFillToolBoxControl::SvxFillToolBoxControl( sal_uInt16 nSlotId, sal_uInt16 nId, ToolBox& rTbx ) :
     SfxToolBoxControl( nSlotId, nId, rTbx ),
 
     pStyleItem		( NULL ),
@@ -78,8 +78,8 @@ SvxFillToolBoxControl::SvxFillToolBoxControl( USHORT nSlotId, USHORT nId, ToolBo
     pFillControl	( NULL ),
     pFillTypeLB		( NULL ),
     pFillAttrLB		( NULL ),
-    bUpdate			( FALSE ),
-    bIgnoreStatusUpdate( FALSE ),
+    bUpdate			( sal_False ),
+    bIgnoreStatusUpdate( sal_False ),
     eLastXFS        ( XFILL_NONE )
 {
     addStatusListener( rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( ".uno:FillColor" )));
@@ -107,7 +107,7 @@ SvxFillToolBoxControl::~SvxFillToolBoxControl()
 
 void SvxFillToolBoxControl::StateChanged(
 
-    USHORT nSID, SfxItemState eState, const SfxPoolItem* pState )
+    sal_uInt16 nSID, SfxItemState eState, const SfxPoolItem* pState )
 
 {
     bool bEnableControls = false;
@@ -136,11 +136,11 @@ void SvxFillToolBoxControl::StateChanged(
                 pFillTypeLB->Enable();
 
                 eLastXFS = pFillTypeLB->GetSelectEntryPos();
-                bUpdate = TRUE;
+                bUpdate = sal_True;
 
                 XFillStyle eXFS = (XFillStyle)pStyleItem->GetValue();
                 pFillTypeLB->SelectEntryPos(
-                    sal::static_int_cast< USHORT >( eXFS ) );
+                    sal::static_int_cast< sal_uInt16 >( eXFS ) );
                 pFillAttrLB->Enable();
             }
             else if( pStyleItem )
@@ -185,9 +185,9 @@ void SvxFillToolBoxControl::StateChanged(
                 //pFillTypeLB->Enable();
                 pFillAttrLB->Enable();
 
-                bUpdate = TRUE;
+                bUpdate = sal_True;
             }
-
+        
             Update( pState );
         }
         else
@@ -198,7 +198,7 @@ void SvxFillToolBoxControl::StateChanged(
                 pFillTypeLB->SetNoSelection();
                 pFillAttrLB->Disable();
                 pFillAttrLB->SetNoSelection();
-                bUpdate = FALSE;
+                bUpdate = sal_False;
             }
             else
             {
@@ -212,7 +212,7 @@ void SvxFillToolBoxControl::StateChanged(
                     ( nSID == SID_ATTR_FILL_BITMAP 	 && eXFS == XFILL_BITMAP ) )
                 {
                     pFillAttrLB->SetNoSelection();
-                    //bUpdate = FALSE;
+                    //bUpdate = sal_False;
                 }
             }
         }
@@ -232,7 +232,7 @@ void SvxFillToolBoxControl::Update( const SfxPoolItem* pState )
 {
     if ( pStyleItem && pState && bUpdate )
     {
-        bUpdate = FALSE;
+        bUpdate = sal_False;
 
         XFillStyle eXFS = (XFillStyle)pStyleItem->GetValue();
 
@@ -266,7 +266,7 @@ void SvxFillToolBoxControl::Update( const SfxPoolItem* pState )
                         LISTBOX_ENTRY_NOTFOUND ||
                         pFillAttrLB->GetSelectEntryColor() != aColor )
                     {
-                        USHORT nCount = pFillAttrLB->GetEntryCount();
+                        sal_uInt16 nCount = pFillAttrLB->GetEntryCount();
                         String aTmpStr;
                         if( nCount > 0 )
                         {
@@ -282,9 +282,9 @@ void SvxFillToolBoxControl::Update( const SfxPoolItem* pState )
                         aTmpStr += aString;
                         aTmpStr += TMP_STR_END;
 
-                        //pFillAttrLB->SetUpdateMode( FALSE );
-                        USHORT nPos = pFillAttrLB->InsertEntry( aColor, aTmpStr );
-                        //pFillAttrLB->SetUpdateMode( TRUE );
+                        //pFillAttrLB->SetUpdateMode( sal_False );
+                        sal_uInt16 nPos = pFillAttrLB->InsertEntry( aColor, aTmpStr );
+                        //pFillAttrLB->SetUpdateMode( sal_True );
                         pFillAttrLB->SelectEntryPos( nPos );
                     }
                     // NEU
@@ -304,7 +304,7 @@ void SvxFillToolBoxControl::Update( const SfxPoolItem* pState )
                     // Pruefen, ob Eintrag nicht in der Liste ist
                     if( pFillAttrLB->GetSelectEntry() != aString )
                     {
-                        USHORT nCount = pFillAttrLB->GetEntryCount();
+                        sal_uInt16 nCount = pFillAttrLB->GetEntryCount();
                         String aTmpStr;
                         if( nCount > 0 )
                         {
@@ -324,7 +324,7 @@ void SvxFillToolBoxControl::Update( const SfxPoolItem* pState )
                         String aEmptyString = String();
                          XGradientList aGradientList( aEmptyString );
                         aGradientList.Insert( pEntry );
-                        aGradientList.SetDirty( FALSE );
+                        aGradientList.SetDirty( sal_False );
                         Bitmap* pBmp = aGradientList.CreateBitmapForUI( 0 );
 
                         if( pBmp )
@@ -354,7 +354,7 @@ void SvxFillToolBoxControl::Update( const SfxPoolItem* pState )
                     // Pruefen, ob Eintrag nicht in der Liste ist
                     if( pFillAttrLB->GetSelectEntry() != aString )
                     {
-                        USHORT nCount = pFillAttrLB->GetEntryCount();
+                        sal_uInt16 nCount = pFillAttrLB->GetEntryCount();
                         String aTmpStr;
                         if( nCount > 0 )
                         {
@@ -374,7 +374,7 @@ void SvxFillToolBoxControl::Update( const SfxPoolItem* pState )
                         String aEmptyString = String();
                         XHatchList aHatchList( aEmptyString );
                         aHatchList.Insert( pEntry );
-                        aHatchList.SetDirty( FALSE );
+                        aHatchList.SetDirty( sal_False );
                         Bitmap* pBmp = aHatchList.CreateBitmapForUI( 0 );
 
                         if( pBmp )
@@ -411,7 +411,7 @@ void SvxFillToolBoxControl::Update( const SfxPoolItem* pState )
                     // Pruefen, ob Eintrag nicht in der Liste ist
                     if( pFillAttrLB->GetSelectEntry() != aString )
                     {
-                        USHORT nCount = pFillAttrLB->GetEntryCount();
+                        sal_uInt16 nCount = pFillAttrLB->GetEntryCount();
                         String aTmpStr;
                         if( nCount > 0 )
                         {
@@ -430,7 +430,7 @@ void SvxFillToolBoxControl::Update( const SfxPoolItem* pState )
                         XBitmapEntry* pEntry = new XBitmapEntry( pBitmapItem->GetBitmapValue(), aTmpStr );
                         XBitmapList aBitmapList( String::CreateFromAscii("TmpList") );
                         aBitmapList.Insert( pEntry );
-                        aBitmapList.SetDirty( FALSE );
+                        aBitmapList.SetDirty( sal_False );
                         //Bitmap* pBmp = aBitmapList.GetBitmap( 0 );
                         //( (ListBox*)pFillAttrLB )->InsertEntry( pEntry->GetName(), *pBmp );
                         pFillAttrLB->Fill( &aBitmapList );
@@ -446,7 +446,7 @@ void SvxFillToolBoxControl::Update( const SfxPoolItem* pState )
             break;
 
             default:
-                DBG_ERROR( "Nicht unterstuetzter Flaechentyp" );
+                OSL_FAIL( "Nicht unterstuetzter Flaechentyp" );
             break;
         }
     }
@@ -678,7 +678,7 @@ IMPL_LINK( FillControl, SelectFillAttrHdl, ListBox *, pBox )
 {
     XFillStyle eXFS = (XFillStyle)pLbFillType->GetSelectEntryPos();
     XFillStyleItem aXFillStyleItem( eXFS );
-    BOOL bAction = pBox && !pLbFillAttr->IsTravelSelect();
+    sal_Bool bAction = pBox && !pLbFillAttr->IsTravelSelect();
 
     SfxObjectShell* pSh = SfxObjectShell::Current();
     if ( bAction )
@@ -690,10 +690,10 @@ IMPL_LINK( FillControl, SelectFillAttrHdl, ListBox *, pBox )
         aArgs[0].Name = ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "FillStyle" ));
         aXFillStyleItem.QueryValue(  a );
         aArgs[0].Value = a;
-        ( (SvxFillToolBoxControl*)GetData() )->IgnoreStatusUpdate( TRUE );
+        ( (SvxFillToolBoxControl*)GetData() )->IgnoreStatusUpdate( sal_True );
         ((SvxFillToolBoxControl*)GetData())->Dispatch( 
             ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( ".uno:FillStyle" )), aArgs );
-        ( (SvxFillToolBoxControl*)GetData() )->IgnoreStatusUpdate( FALSE );
+        ( (SvxFillToolBoxControl*)GetData() )->IgnoreStatusUpdate( sal_False );
 
         switch( eXFS )
         {
@@ -724,7 +724,7 @@ IMPL_LINK( FillControl, SelectFillAttrHdl, ListBox *, pBox )
             break;
             case XFILL_GRADIENT:
             {
-                USHORT nPos = pLbFillAttr->GetSelectEntryPos();
+                sal_uInt16 nPos = pLbFillAttr->GetSelectEntryPos();
 
                 if ( nPos != LISTBOX_ENTRY_NOTFOUND && pSh && pSh->GetItem( SID_GRADIENT_LIST ) )
                 {
@@ -748,7 +748,7 @@ IMPL_LINK( FillControl, SelectFillAttrHdl, ListBox *, pBox )
 
             case XFILL_HATCH:
             {
-                USHORT nPos = pLbFillAttr->GetSelectEntryPos();
+                sal_uInt16 nPos = pLbFillAttr->GetSelectEntryPos();
 
                 if ( nPos != LISTBOX_ENTRY_NOTFOUND && pSh && pSh->GetItem( SID_HATCH_LIST ) )
                 {
@@ -771,7 +771,7 @@ IMPL_LINK( FillControl, SelectFillAttrHdl, ListBox *, pBox )
 
             case XFILL_BITMAP:
             {
-                USHORT nPos = pLbFillAttr->GetSelectEntryPos();
+                sal_uInt16 nPos = pLbFillAttr->GetSelectEntryPos();
 
                 if ( nPos != LISTBOX_ENTRY_NOTFOUND && pSh && pSh->GetItem( SID_BITMAP_LIST ) )
                 {
@@ -820,9 +820,6 @@ void FillControl::Resize()
     pLbFillType->SetSizePixel( Size( nW * 2 - nSep, nH ) );
     pLbFillAttr->SetPosSizePixel( Point( nW * 2 + nSep, 0 ), Size( nW * 3 - nSep, nH ) );
 }
-/* -----------------------------08.03.2002 15:04------------------------------
-
- ---------------------------------------------------------------------------*/
 
 void FillControl::DataChanged( const DataChangedEvent& rDCEvt )
 {
